Skip to contents

ActiveCA is an Open Data Product that provides analysis-ready data from the General Social Survey of Canada Cycles 2 (1986), 7 (1992), 12 (1998), 19 (2005), 24 (2010), 29 (2015), and 34 (2022) regarding active travel. These data can be used to study walking and cycling in Canada for various purposes over time, and to calculate impedance functions for accessibility analysis. The package provides pre-estimated impedance functions for cycling and walking trips for Census Agglomerations and Census Metropolitan Areas.

Author

Maintainer: Bruno Dos Santos dossanb@mcmaster.ca (ORCID)

Authors:

Other contributors:

  • Statistics Canada (Copyright holder of the Public Use Microdata Files of the General Social Survey. These files are released using Statistics Canada Open Licence) [copyright holder]