Skip to contents

This dataset contains some socioeconomic variables obtained from the main file of the 1986 GSS Time Use Survey (Cycle 2). We labeled variables according to the Public Use Micro Data File Documentation and User's Guide (gss-12M0002-E-1986-c-2-main).

Usage

data(gss_main_1986)

Format

A data frame containing 16390 rows and 9 variables; each row represents a unique respondent.

SEQNUM

Record identification.

FWGT_OS

Final Weight for Main File.

DVAGEGR

Age group of respondent.

DVSEX

Sex of the respondent.

DVMARST

Marital status of the respondent.

DVHHLDSZ

Household size.

PROV

Province of residence of the respondent.

DVCHILD

Number of children.